#
# spec file for package python-senlinclient
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global sname python-senlinclient
Name:           python-senlinclient
Version:        1.2.0
Release:        1.3
Summary:        Python API and CLI for OpenStack Senlin
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://launchpad.net/%{sname}
Source0:        https://pypi.io/packages/source/p/%{sname}/%{sname}-%{version}.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python-Babel >= 2.3.4
BuildRequires:  python-PrettyTable >= 0.7.1
BuildRequires:  python-PyYAML >= 3.10.0
BuildRequires:  python-appdirs >= 1.3.0
BuildRequires:  python-devel
BuildRequires:  python-fixtures >= 3.0.0
BuildRequires:  python-heatclient >= 1.6.1
BuildRequires:  python-jsonschema >= 2.0.0
BuildRequires:  python-mock >= 2.0
BuildRequires:  python-openstackclient >= 3.3.0
BuildRequires:  python-openstacksdk >= 0.9.10
BuildRequires:  python-os-testr >= 0.8.0
BuildRequires:  python-osc-lib >= 1.2.0
BuildRequires:  python-oslo.i18n >= 2.1.0
BuildRequires:  python-oslo.serialization >= 1.10.0
BuildRequires:  python-oslo.utils >= 3.18.0
BuildRequires:  python-oslotest >= 1.10.0
BuildRequires:  python-pbr >= 1.8
BuildRequires:  python-python-subunit >= 0.0.18
BuildRequires:  python-requests >= 2.10.0
BuildRequires:  python-requests-mock >= 1.1
BuildRequires:  python-testtools >= 1.4.0
Requires:       python-PrettyTable >= 0.7.1
Requires:       python-PyYAML >= 3.10.0
Requires:       python-appdirs >= 1.3.0
Requires:       python-heatclient >= 1.6.1
Requires:       python-jsonschema >= 2.0.0
Requires:       python-keystoneauth1 >= 2.17.0
Requires:       python-openstackclient >= 3.3.0
Requires:       python-openstacksdk >= 0.9.10
Requires:       python-osc-lib >= 1.2.0
Requires:       python-oslo.i18n >= 2.1.0
Requires:       python-oslo.serialization >= 1.10.0
Requires:       python-oslo.utils >= 3.18.0
Requires:       python-pbr >= 1.8
Requires:       python-requests >= 2.10.0
Requires:       python-six >= 1.9.0
BuildArch:      noarch

%description
OpenStack Clustering service Provisioning API Client Library

This is a client for the OpenStack Senlin API. It provides a Python API (the
senlinclient module) and a command-line interface (senlin).

%package doc
Summary:        Documentation for OpenStack Senlin API Client
Group:          Documentation
BuildRequires:  python-Sphinx
BuildRequires:  python-oslosphinx >= 4.7.0
BuildRequires:  python-reno >= 1.8.0

%description doc
This is a client for the OpenStack Senlin API and a command-line script (senlin).
Each implements 100% of the OpenStack Senlin API. This package contains
auto-generated documentation.

%prep
%autosetup -n %{sname}-%{version}
%py_req_cleanup

%build
%{py2_build}

%{__python2} setup.py build_sphinx
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%{py2_install}
# bash completion
install -p -D -m 644 tools/senlin.bash_completion %{buildroot}%{_sysconfdir}/bash_completion.d/senlin.bash_completion

%check
%{__python2} setup.py testr

%files
%license LICENSE
%doc README.rst
%{_bindir}/senlin
%{python2_sitelib}/senlinclient
%{python2_sitelib}/*.egg-info
%{_bindir}/senlin
%{_sysconfdir}/bash_completion.d/senlin.bash_completion

%files doc
%license LICENSE
%doc doc/build/html

%changelog
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 1.2.0:
  - Fix help msg of node-check and node-recover
  - Replace 'MagicMock' with 'Mock'
  - Fix 'type_name' in `openstack cluster profile list`
  - Add AUTHORS and ChangeLog into gitignore
  - Delete python bytecode file
  - key=value should be key2=value2
  - Fix cluster_id field when listing events
  - fix indentation of reno toctree
  - Fix receiver list
  - Add Constraints support
  - Make shell main() specify return value in exit code
  - Changed the link to home-page
  - Show team and repo badges on README
  - Add plug-in summary for osc doc
  - Add sort key "oid" in event list
  - Fix target ID display when listing actions
  - Fix `openstack  cluster profile validate` bug
  - Fix error in policy-show
  - Trivial: Modify the description of profile validate
  - Fix error in build-info
  - Fix `openstack  cluster policy vaildate` bug
  - Revise help string profile list
  - Revise key1=value to key1=value1
  - Add missing requirements
  - Updated from global requirements
  - Fix error in do_profile_type_list
  - Change osprofiler option "--profile" to "--os-profile"
  - Add receiver type instruction
  - Release note for python-senlinclient 1.1.0
  - Show 'dependents' property in node details
  - Fix cluster_collect interface
  - Fix resource update issues
  - Fix `openstack cluster event list` bug
  - Revise the help message of policy binding list
  - Revise the help message of cluster-collect
  - revise the "cluster-policy-attach"
  - Revise "enabled" related code in ClusterPolicyUpdate
  - Modify several marker's help
  - Remove six.moves module
  - Revise the help info of cluster collect
  - Fix `openstack cluster action list` bug
  - Add metadata clean help
  - Fix import method to follow community guideline
  - Fix doc build if git is absent
  - Correct deprecation of scale-in and scale-out cli
  - Enhance the parameter check for "path" in cluster collect
  - Revise 'openstack cluster node members list'
  - The output of action list filtered by "target" returns empty
  - Remove unsupported sort key "user"
  - Fix error in action list
  - Add deprecation of cluster-run cli
  - Fix senlin cluster-policy-detach cannot disable
  - cluster policy attach cannot work
  - Client support for node replace
  - action-list's given id not event id
  - All dictionary options need be a string
  - The output of event-list by filter "cluster_id" return empty
  - Add filters "policy_type" and "policy_name" for policy binding list
  - Rework take_action function in class ListAction
  - Policy binding attach cannot work
  - Update reno for stable/newton
  - Fix list of event with timestamp field
  - Support  "global_project" arguments for action-list
  - Rework do_action_list function's "full_id" handling
  - Revert "Fix `openstack  cluster profile validate` bug"
  - senlin profile-create has no argument -t
  - Add filter "is_enabled" for policy binding list
  - Trivial: Modify the description of policy validate
  - Fix project_id show in 'senlin xyz_list -g'
  - Fix error in cluster collect
  - policy binding update cannot work
  - Point out valid sort keys in `openstack cluster member list`
  - Add "cluster_id" column to  `openstack cluster event list`
  - Point out valid filter keys in `openstack cluster member list`
  - Support xyz_update purging metadata
  - Release note for python-senlinclient 1.2.0
  - Enable release notes translation
  - Trivial: Fix a typo in cluster-run's error message
  - Change the type of the parameter "enabled" to boolean
  - Fix `openstack  cluster policy show` bug
  - Fix the incorrect version and release details
  - Profile list can not display the "type" column
  - Remove unnecessary coding format in the head of files
  - Get project_id and user_id when show profile
  - profile's name also can be use in some commands
  - event-list cannot display correctly according to the sort option
  - Fix profile list
  - Show project_id field when xyz-list with global-project
  - `openstack cluster event list --help` bug
  - Revert "Revert "Fix `openstack  cluster profile validate` bug""
  - Revert "Revert "Revert "Fix `openstack  cluster profile validate` bug"""
  - Fix error in "action list"
  - Revert "Get project_id and user_id when show profile"
  - Delete pbr generated files
  - Modify development doc url in CONTRIBUTING.rst
  - Revert "Revert "Get project_id and user_id when show profile""
* Fri Jan 27 2017 jengelh@inai.de
- Use more specific RPM group
* Fri Oct 21 2016 tbechtold@suse.com
- Switch to stable/newton
* Thu Oct 13 2016 tbechtold@suse.com
- Initial packaging (version 1.0.0)
